==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateMachineEventDataItemSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.DataItemValueSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.DataItemValueSetImpl;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.EventArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItem;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventParameterReferenceSetImpl;

import java.util.Arrays;
import java.util.List;


public class StateMachineEventDataItemSetImpl extends InstanceSet<StateMachineEventDataItemSet,StateMachineEventDataItem> implements StateMachineEventDataItemSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDescrip( m_Descrip );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDimensions( m_Dimensions );
    }
    @Override
    public void setPrevious_SMedi_ID( UniqueId ref_Previous_SMedi_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setPrevious_SMedi_ID( ref_Previous_SMedi_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setName( m_Name );
    }
    @Override
    public void setSMedi_ID( UniqueId m_SMedi_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSMedi_ID( m_SMedi_ID );
    }


    // selections
    @Override
    public EventArgumentSet R1017_represents_EventArgument() throws XtumlException {
        EventArgumentSet eventargumentset = new EventArgumentSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) eventargumentset.addAll( statemachineeventdataitem.R1017_represents_EventArgument() );
        return eventargumentset;
    }
    @Override
    public DataItemValueSet R2934_DataItemValue() throws XtumlException {
        DataItemValueSet dataitemvalueset = new DataItemValueSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) dataitemvalueset.addAll( statemachineeventdataitem.R2934_DataItemValue() );
        return dataitemvalueset;
    }
    @Override
    public SM_SMSet R516_is_carried_on_events_into_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) sm_smset.add( statemachineeventdataitem.R516_is_carried_on_events_into_SM_SM() );
        return sm_smset;
    }
    @Override
    public DataTypeSet R524_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) datatypeset.add( statemachineeventdataitem.R524_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R531_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) dimensionsset.addAll( statemachineeventdataitem.R531_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public StateMachineEventSet R532_carried_by_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventset.add( statemachineeventdataitem.R532_carried_by_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public StateMachineEventDataItemSet R533_precedes_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitemset.add( statemachineeventdataitem.R533_precedes_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public StateMachineEventDataItemSet R533_succeeds_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitemset.add( statemachineeventdataitem.R533_succeeds_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public EventParameterReferenceSet R846_EventParameterReference() throws XtumlException {
        EventParameterReferenceSet eventparameterreferenceset = new EventParameterReferenceSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) eventparameterreferenceset.addAll( statemachineeventdataitem.R846_EventParameterReference() );
        return eventparameterreferenceset;
    }


    @Override
    public StateMachineEventDataItem nullElement() {
        return StateMachineEventDataItemImpl.EMPTY_STATEMACHINEEVENTDATAITEM;
    }

    @Override
    public StateMachineEventDataItemSet emptySet() {
      return new StateMachineEventDataItemSetImpl();
    }

    @Override
    public StateMachineEventDataItemSet value() {
        return this;
    }

    @Override
    public List<StateMachineEventDataItem> elements() {
        StateMachineEventDataItem[] elements = toArray(new StateMachineEventDataItem[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/StateMachineEventDataItemSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.instance.DataItemValueSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.DataItemValueSetImpl;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.EventArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItem;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventSetImpl;
import io.ciera.tool.sql.ooaofooa.value.EventParameterReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.impl.EventParameterReferenceSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class StateMachineEventDataItemSetImpl extends InstanceSet<StateMachineEventDataItemSet,StateMachineEventDataItem> implements StateMachineEventDataItemSet {

    public StateMachineEventDataItemSetImpl() {
    }

    public StateMachineEventDataItemSetImpl(Comparator<? super StateMachineEventDataItem> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMedi_ID( UniqueId m_SMedi_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setSMedi_ID( m_SMedi_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDimensions( m_Dimensions );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setName( m_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setDescrip( m_Descrip );
    }
    @Override
    public void setPrevious_SMedi_ID( UniqueId ref_Previous_SMedi_ID ) throws XtumlException {
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitem.setPrevious_SMedi_ID( ref_Previous_SMedi_ID );
    }


    // selections
    @Override
    public EventArgumentSet R1017_represents_EventArgument() throws XtumlException {
        EventArgumentSet eventargumentset = new EventArgumentSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) eventargumentset.addAll( statemachineeventdataitem.R1017_represents_EventArgument() );
        return eventargumentset;
    }
    @Override
    public DataItemValueSet R2934_DataItemValue() throws XtumlException {
        DataItemValueSet dataitemvalueset = new DataItemValueSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) dataitemvalueset.addAll( statemachineeventdataitem.R2934_DataItemValue() );
        return dataitemvalueset;
    }
    @Override
    public SM_SMSet R516_is_carried_on_events_into_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) sm_smset.add( statemachineeventdataitem.R516_is_carried_on_events_into_SM_SM() );
        return sm_smset;
    }
    @Override
    public DataTypeSet R524_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) datatypeset.add( statemachineeventdataitem.R524_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public DimensionsSet R531_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) dimensionsset.addAll( statemachineeventdataitem.R531_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public StateMachineEventSet R532_carried_by_StateMachineEvent() throws XtumlException {
        StateMachineEventSet statemachineeventset = new StateMachineEventSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventset.add( statemachineeventdataitem.R532_carried_by_StateMachineEvent() );
        return statemachineeventset;
    }
    @Override
    public StateMachineEventDataItemSet R533_precedes_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitemset.add( statemachineeventdataitem.R533_precedes_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public StateMachineEventDataItemSet R533_succeeds_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) statemachineeventdataitemset.add( statemachineeventdataitem.R533_succeeds_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }
    @Override
    public EventParameterReferenceSet R846_EventParameterReference() throws XtumlException {
        EventParameterReferenceSet eventparameterreferenceset = new EventParameterReferenceSetImpl();
        for ( StateMachineEventDataItem statemachineeventdataitem : this ) eventparameterreferenceset.addAll( statemachineeventdataitem.R846_EventParameterReference() );
        return eventparameterreferenceset;
    }


    @Override
    public StateMachineEventDataItem nullElement() {
        return StateMachineEventDataItemImpl.EMPTY_STATEMACHINEEVENTDATAITEM;
    }

    @Override
    public StateMachineEventDataItemSet emptySet() {
      return new StateMachineEventDataItemSetImpl();
    }

    @Override
    public StateMachineEventDataItemSet emptySet(Comparator<? super StateMachineEventDataItem> comp) {
      return new StateMachineEventDataItemSetImpl(comp);
    }

    @Override
    public StateMachineEventDataItemSet value() {
        return this;
    }

    @Override
    public List<StateMachineEventDataItem> elements() {
        StateMachineEventDataItem[] elements = toArray(new StateMachineEventDataItem[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
